######
config
######

************
globalconfig
************

.. code-block:: python

    from toolbox.config import globalconfig

.. autofunction:: toolbox.config.globalconfig.make_config

    .. autofunction:: toolbox.config.globalconfig.config

    .. autofunction:: toolbox.config.globalconfig.conf
